==> Gambio v4.1.2.0.zip: Vollversion GX v4.1.2.0/Shopsystem/Dateien/lang/german/original_sections/admin/gm_laws.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	gm_laws.lang.inc.php 2018-01-15
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2018 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'BUTTON_SAVE' => 'Speichern',
	'TITLE_LAW' => 'Rechtliches',
	'TITLE_COOKIES' => 'Cookie Hinweis',
	'TITLE_PRIVACY' => 'Datenschutzlink anzeigen',
	'TITLE_PRIVACY_CHECKBOX' => 'Datenschutz mittels Checkbox akzeptieren',
	'TITLE_CONDITIONS' => 'Allgemeine Geschäftsbedingungen',
	'TITLE_WITHDRAWAL' => 'Widerrufsrecht',
	'TITLE_CONDITIONS_SHOW_ORDER' => 'im Bestellvorgang anzeigen',
	'TITLE_CONDITIONS_CHECK_ORDER' => 'im Bestellvorgang bestätigen',
	'TITLE_PRIVACY_SHOW_REGISTRATION' => 'in der Registrierung',
	'TITLE_WITHDRAWAL_SHOW_ORDER' => 'im Bestellvorgang anzeigen',
	'TITLE_WITHDRAWAL_CHECK_ORDER' => 'im Bestellvorgang bestätigen',
	'TITLE_WITHDRAWAL_CONTENT_ID_ORDER' => 'Content ID',
	'TITLE_WITHDRAWAL_WEBFORM_ACTIVE' => 'Webformular anbieten',
	'TITLE_WITHDRAWAL_PDF_ACTIVE' => 'PDF-Formular anbieten',
	'TITLE_SHOW_ACCOUNT_WITHDRAWAL_LINK' => 'Widerrufsrecht-Link innerhalb der Bestellinformationen unter Mein Konto anzeigen',
	'TITLE_ATTACH_CONDITIONS_OF_USE_IN_ORDER_CONFIRMATION' => 'AGB als PDF an Bestellbestätigung anhängen',
	'ATTACH_PRIVACY_NOTICE_IN_ORDER_CONFIRMATION' => 'Datenschutzerklärung als PDF an Bestellbestätigung anhängen',
	'TITLE_ATTACH_WITHDRAWAL_INFO_IN_ORDER_CONFIRMATION' => 'Widerrufsbelehrung als PDF an Bestellbestätigung anhängen',
	'TITLE_ATTACH_WITHDRAWAL_FORM_IN_ORDER_CONFIRMATION' => 'Widerrufsformular als PDF an Bestellbestätigung anhängen',
	'TITLE_DOWNLOAD_DELAY_FOR_ABANDONMENT_OF_WITHDRAWL_RIGHT' => 'Downloadverzögerung bei Verzicht auf das Widerrufsrecht',
	'TITLE_DOWNLOAD_DELAY_WITHOUT_ABANDONMENT_OF_WITHDRAWL_RIGHT' => 'Downloadverzögerung ohne Verzicht auf das Widerrufsrecht',
	'TITLE_CHECK_ABANDONMENT_OF_WITHDRAWL_DOWNLOAD' => 'Verzicht auf Widerrufsrecht für Download-Artikel als Pflichtfeld',
	'TITLE_CHECK_ABANDONMENT_OF_WITHDRAWL_SERVICE' => 'Verzicht auf Widerrufsrecht für Dienstleistungen als Pflichtfeld',
	'TITLE_SHOW_ABANDONMENT_OF_WITHDRAWL_DOWNLOAD' => 'Verzicht auf Widerrufsrecht für Download-Artikel anzeigen',
	'TITLE_SHOW_ABANDONMENT_OF_WITHDRAWL_SERVICE' => 'Verzicht auf Widerrufsrecht für Dienstleistungen anzeigen',
	'DESCIPTION_DOWNLOAD_DELAY_WITHOUT_ABANDONMENT_OF_WITHDRAWL_RIGHT' => 'Format: DD:HH:MM:SS',
	'TITLE_CONFIRMATION' => 'Bestellbestätigung-Seite',
	'TITLE_PRIVACY_CONFIRMATION' => 'Datenschutzerklärung-Link anzeigen',
	'TITLE_CONDITIONS_CONFIRMATION' => 'AGB-Link anzeigen',
	'TITLE_WITHDRAWAL_CONFIRMATION' => 'Widerrufsrecht-Link anzeigen',
	'TEXT_LOG_IP' => 'im Bestellvorgang IP speichern',
	'TEXT_CONFIRM_IP' => 'im Bestellvorgang IP-Logging bestätigen',
	'TEXT_LOG_IP_LOGIN' => 'bei Login und Registrierung IP speichern',
	'TEXT_NOTE_LOGGING' => 'Hinweis: IP-Adressen von Benutzern dürfen personenbezogen nur gespeichert werden, soweit hierfür eine ausdrückliche Einwilligung erteilt wurde.',
	'TITLE_DISPLAY_TAX' => 'Mehrwertsteuer-Anzeige',
	'TEXT_DISPLAY_TAX' => 'Mehrwertsteuer unter Artikelpreisen anzeigen',
	'TEXT_DISPLAY_TAX_EQ_0' => 'Auch Mehrwertsteuer anzeigen, wenn diese gleich 0 sind',
	'TITLE_PRIVACY_CALLBACK' => 'im Callback Service',
	'TITLE_PRIVACY_CONTACT' => 'im Kontaktformular',
	'TITLE_PRIVACY_TELL_A_FRIEND' => 'im "Frage zum Produkt"-Modul',
	'TITLE_PRIVACY_FOUND_CHEAPER' => 'im "Woanders günstiger"-Modul',
	'TITLE_PRIVACY_REVIEWS' => 'im Artikelbewertungsformular',
	'TITLE_PRIVACY_ACCOUNT_CONTACT' => 'im Kundenbereich unter "Kontodaten bearbeiten"',
	'TITLE_PRIVACY_ACCOUNT_ADDRESS_BOOK' => 'im Kundenbereich unter "Adressbuch bearbeiten"',
	'TITLE_PRIVACY_ACCOUNT_NEWSLETTER' => 'in der Newsletterregistrierung',
	'TITLE_PRIVACY_CHECKOUT_SHIPPING' => 'im Bestellvorgang unter "Versandadresse"',
	'TITLE_PRIVACY_CHECKOUT_PAYMENT' => 'im Bestellvorgang unter "Rechnungsadresse"',
	'TITLE_LOG_IP' => 'IP-Logging',
	'TITLE_STATUS' => 'Status',
	'TITLE_POSITION' => 'Position',
	'TITLE_COLOR' => 'Farbe',
	'TITLE_TRANSPARENCY' => 'Transparenz',
	'TITLE_CLOSE_ICON' => 'Schließen-Icon',
	'TITLE_BUTTON_TEXT' => 'Button-Text',
	'TITLE_BUTTON_TEXT_COLOR' => 'Button-Text Farbe',
	'TITLE_BUTTON_COLOR' => 'Button-Farbe',
	'TITLE_BUTTON_LINK' => 'Button-Link',
	'TITLE_CONTENT' => 'Inhalt',
	'BUTTON_SELECT_COLOR' => 'Farbe wählen',
	'OPTION_POSITION_TOP' => 'oben',
	'OPTION_POSITION_BOTTOM' => 'unten',
	'TITLE_DATA_TRANSFER_TO_TRANSPORT_COMPANIES' => 'Datenweitergabe an Transportunternehmen',
	'TITLE_DATA_TRANSFER_TO_TRANSPORT_COMPANIES_STATUS_LABEL' => 'im Bestellvorgang anzeigen',
	'TITLE_DATA_TRANSFER_TO_TRANSPORT_COMPANIES_REQUIRED_LABEL' => 'im Bestellvorgang bestätigen',
	'TITLE_DATA_TRANSFER_TO_TRANSPORT_COMPANIES_LABEL' => 'Anzeige für Versandart: '
);

==> Gambio v5.0.2.0.zip: Vollversion GX v5.0.2.0/Shopsystem/Dateien/lang/german/original_sections/admin/gm_laws.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	gm_laws.lang.inc.php 2018-01-15
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2018 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'BUTTON_SAVE' => 'Speichern',
	'TITLE_LAW' => 'Rechtliches',
	'TITLE_COOKIES' => 'Cookie Hinweis',
	'TITLE_PRIVACY' => 'Datenschutzlink anzeigen',
	'TITLE_PRIVACY_CHECKBOX' => 'Datenschutz mittels Checkbox akzeptieren',
	'TITLE_CONDITIONS' => 'Allgemeine Geschäftsbedingungen',
	'TITLE_WITHDRAWAL' => 'Widerrufsrecht',
	'TITLE_CONDITIONS_SHOW_ORDER' => 'im Bestellvorgang anzeigen',
	'TITLE_CONDITIONS_CHECK_ORDER' => 'im Bestellvorgang bestätigen',
	'TITLE_PRIVACY_SHOW_REGISTRATION' => 'in der Registrierung',
	'TITLE_WITHDRAWAL_SHOW_ORDER' => 'im Bestellvorgang anzeigen',
	'TITLE_WITHDRAWAL_CHECK_ORDER' => 'im Bestellvorgang bestätigen',
	'TITLE_WITHDRAWAL_CONTENT_ID_ORDER' => 'Content ID',
	'TITLE_WITHDRAWAL_WEBFORM_ACTIVE' => 'Webformular anbieten',
	'TITLE_WITHDRAWAL_PDF_ACTIVE' => 'PDF-Formular anbieten',
	'TITLE_SHOW_ACCOUNT_WITHDRAWAL_LINK' => 'Widerrufsrecht-Link innerhalb der Bestellinformationen unter Mein Konto anzeigen',
	'TITLE_ATTACH_CONDITIONS_OF_USE_IN_ORDER_CONFIRMATION' => 'AGB als PDF an Bestellbestätigung anhängen',
	'ATTACH_PRIVACY_NOTICE_IN_ORDER_CONFIRMATION' => 'Datenschutzerklärung als PDF an Bestellbestätigung anhängen',
	'TITLE_ATTACH_WITHDRAWAL_INFO_IN_ORDER_CONFIRMATION' => 'Widerrufsbelehrung als PDF an Bestellbestätigung anhängen',
	'TITLE_ATTACH_WITHDRAWAL_FORM_IN_ORDER_CONFIRMATION' => 'Widerrufsformular als PDF an Bestellbestätigung anhängen',
	'TITLE_DOWNLOAD_DELAY_FOR_ABANDONMENT_OF_WITHDRAWL_RIGHT' => 'Downloadverzögerung bei Verzicht auf das Widerrufsrecht',
	'TITLE_DOWNLOAD_DELAY_WITHOUT_ABANDONMENT_OF_WITHDRAWL_RIGHT' => 'Downloadverzögerung ohne Verzicht auf das Widerrufsrecht',
	'TITLE_CHECK_ABANDONMENT_OF_WITHDRAWL_DOWNLOAD' => 'Verzicht auf Widerrufsrecht für Download-Artikel als Pflichtfeld',
	'TITLE_CHECK_ABANDONMENT_OF_WITHDRAWL_SERVICE' => 'Verzicht auf Widerrufsrecht für Dienstleistungen als Pflichtfeld',
	'TITLE_SHOW_ABANDONMENT_OF_WITHDRAWL_DOWNLOAD' => 'Verzicht auf Widerrufsrecht für Download-Artikel anzeigen',
	'TITLE_SHOW_ABANDONMENT_OF_WITHDRAWL_SERVICE' => 'Verzicht auf Widerrufsrecht für Dienstleistungen anzeigen',
	'DESCIPTION_DOWNLOAD_DELAY_WITHOUT_ABANDONMENT_OF_WITHDRAWL_RIGHT' => 'Format: DD:HH:MM:SS',
	'TITLE_CONFIRMATION' => 'Bestellbestätigung-Seite',
	'TITLE_PRIVACY_CONFIRMATION' => 'Datenschutzerklärung-Link anzeigen',
	'TITLE_CONDITIONS_CONFIRMATION' => 'AGB-Link anzeigen',
	'TITLE_WITHDRAWAL_CONFIRMATION' => 'Widerrufsrecht-Link anzeigen',
	'TEXT_LOG_IP' => 'im Bestellvorgang IP speichern',
	'TEXT_CONFIRM_IP' => 'im Bestellvorgang IP-Logging bestätigen',
	'TEXT_LOG_IP_LOGIN' => 'bei Login und Registrierung IP speichern',
	'TEXT_NOTE_LOGGING' => 'Hinweis: IP-Adressen von Benutzern dürfen personenbezogen nur gespeichert werden, soweit hierfür eine ausdrückliche Einwilligung erteilt wurde.',
	'TITLE_DISPLAY_TAX' => 'Mehrwertsteuer-Anzeige',
	'TEXT_DISPLAY_TAX' => 'Mehrwertsteuer unter Artikelpreisen anzeigen',
	'TEXT_DISPLAY_TAX_EQ_0' => 'Auch Mehrwertsteuer anzeigen, wenn diese gleich 0 ist',
	'TITLE_PRIVACY_CALLBACK' => 'im Callback Service',
	'TITLE_PRIVACY_CONTACT' => 'im Kontaktformular',
	'TITLE_PRIVACY_TELL_A_FRIEND' => 'im "Frage zum Produkt"-Modul',
	'TITLE_PRIVACY_FOUND_CHEAPER' => 'im "Woanders günstiger"-Modul',
	'TITLE_PRIVACY_REVIEWS' => 'im Artikelbewertungsformular',
	'TITLE_PRIVACY_ACCOUNT_CONTACT' => 'im Kundenbereich unter "Kontodaten bearbeiten"',
	'TITLE_PRIVACY_ACCOUNT_ADDRESS_BOOK' => 'im Kundenbereich unter "Adressbuch bearbeiten"',
	'TITLE_PRIVACY_ACCOUNT_NEWSLETTER' => 'in der Newsletterregistrierung',
	'TITLE_PRIVACY_CHECKOUT_SHIPPING' => 'im Bestellvorgang unter "Versandadresse"',
	'TITLE_PRIVACY_CHECKOUT_PAYMENT' => 'im Bestellvorgang unter "Rechnungsadresse"',
	'TITLE_LOG_IP' => 'IP-Logging',
	'TITLE_STATUS' => 'Status',
	'TITLE_POSITION' => 'Position',
	'TITLE_COLOR' => 'Farbe',
	'TITLE_TRANSPARENCY' => 'Transparenz',
	'TITLE_CLOSE_ICON' => 'Schließen-Icon',
	'TITLE_BUTTON_TEXT' => 'Button-Text',
	'TITLE_BUTTON_TEXT_COLOR' => 'Button-Text Farbe',
	'TITLE_BUTTON_COLOR' => 'Button-Farbe',
	'TITLE_BUTTON_LINK' => 'Button-Link',
	'TITLE_CONTENT' => 'Inhalt',
	'BUTTON_SELECT_COLOR' => 'Farbe wählen',
	'OPTION_POSITION_TOP' => 'oben',
	'OPTION_POSITION_BOTTOM' => 'unten',
	'TITLE_DATA_TRANSFER_TO_TRANSPORT_COMPANIES' => 'Datenweitergabe an Transportunternehmen',
	'TITLE_DATA_TRANSFER_TO_TRANSPORT_COMPANIES_STATUS_LABEL' => 'im Bestellvorgang anzeigen',
	'TITLE_DATA_TRANSFER_TO_TRANSPORT_COMPANIES_REQUIRED_LABEL' => 'im Bestellvorgang bestätigen',
	'TITLE_DATA_TRANSFER_TO_TRANSPORT_COMPANIES_LABEL' => 'Anzeige für Versandart: '
);
